#include <ESP8266WiFi.h>
#include <ESP8266mDNS.h>
#include <WiFiUdp.h>
#include <ArduinoOTA.h>

/* fill your ssid and password here */
const char* ssid = "TR-2";
const char* password = "AQW112";

int greenledPin = 5;//green led attached to ESP8266 ESP-12E module GPIO pin 5
int redledPin = 4;//red led attached to ESP8266 ESP-12E module GPIO pin 4
void setup() {

  Serial.begin(115200);
  /* connect to wifi */
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  /* Wait for connection */
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  /* set pins as output */
  pinMode(greenledPin, OUTPUT);
  pinMode(redledPin, OUTPUT);
  /* create a connection at port 8266 */
  ArduinoOTA.setPort(8266);
  /* Hostname defaults to esp8266-[ChipID] */
  ArduinoOTA.setHostname("myesp8266");

  /* we set password for updating */
  ArduinoOTA.setPassword("admin");
  /* this callback function will be invoked when updating start */
  ArduinoOTA.onStart([]() {
    Serial.println("Start updating");
  });
  /* this callback function will be invoked when updating end */
  ArduinoOTA.onEnd([]() {
    Serial.println("\nEnd updating");
  });
  /* this callback function will be invoked when a number of chunks of software was flashed
    so we can use it to calculate the progress of flashing */
  ArduinoOTA.onProgress([](unsigned int progress, unsigned int total) {
    Serial.printf("Progress: %u%%\r", (progress / (total / 100)));
  });

  /* this callback function will be invoked when updating error */
  ArduinoOTA.onError([](ota_error_t error) {
    Serial.printf("Error[%u]: ", error);
    if (error == OTA_AUTH_ERROR) Serial.println("Auth Failed");
    else if (error == OTA_BEGIN_ERROR) Serial.println("Begin Failed");
    else if (error == OTA_CONNECT_ERROR) Serial.println("Connect Failed");
    else if (error == OTA_RECEIVE_ERROR) Serial.println("Receive Failed");
    else if (error == OTA_END_ERROR) Serial.println("End Failed");
  });
  /* start updating */
  ArduinoOTA.begin();
  Serial.print("ESP8266 IP address: ");
  Serial.println(WiFi.localIP());
}

void loop() {
  /* this function will handle incomming chunk of SW, flash and respond sender */
  ArduinoOTA.handle();
  digitalWrite(greenledPin, LOW);//green led off
  delay(1000);
  digitalWrite(greenledPin, HIGH);//green led on
  delay(1000);
  digitalWrite(redledPin, LOW);//red led off

}
